Alistair Leslie-Hughes : winmm: Increase tolerance range.

Alexandre Julliard julliard at winehq.org
Wed Nov 12 07:18:44 CST 2008


Module: wine
Branch: master
Commit: aa50cd316c58638c834a7bf68aa6eae67c5e9d93
URL:    http://source.winehq.org/git/wine.git/?a=commit;h=aa50cd316c58638c834a7bf68aa6eae67c5e9d93

Author: Alistair Leslie-Hughes <leslie_alistair at hotmail.com>
Date:   Wed Nov  5 22:03:45 2008 +1100

winmm: Increase tolerance range.

---

 dlls/winmm/tests/wave.c |    6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/dlls/winmm/tests/wave.c b/dlls/winmm/tests/wave.c
index 09b0f46..fc6f0ff 100644
--- a/dlls/winmm/tests/wave.c
+++ b/dlls/winmm/tests/wave.c
@@ -789,13 +789,13 @@ static void wave_out_test_deviceOut(int device, double duration,
             }
         }
 
         /* Check the sound duration was between -2% and +10% of the expected value */
         end=GetTickCount();
         actual = (end - start) / 1000.0;
         if (winetest_debug > 1)
             trace("sound duration=%g ms\n",1000*actual);
-        ok((actual > (0.97 * (duration+paused))) &&
-           (actual < (1.1 * (duration+paused))),
+        ok((actual > (0.9 * (duration+paused))) &&
+           (actual < (1.25 * (duration+paused))),
            "The sound played for %g ms instead of %g ms\n",
            1000*actual,1000*(duration+paused));
         for (i = 0; i < headers; i++) {
@@ -789,13 +789,13 @@ static void wave_out_test_deviceOut(int device, double duration,
         }
 
-        /* Check the sound duration was between -2% and +10% of the expected value */
+        /* Check the sound duration was between -10% and +25% of the expected value */
         end=GetTickCount();
         actual = (end - start) / 1000.0;




More information about the wine-cvs mailing list